@@ -139,17 +139,6 @@ class ValueToLPDTO(BaseModel):
     sE410: float
     aversionRiskFactor: float
     m_0: float
-
-class ValueFromLPDTO(BaseModel):
-    farmId: int
-    yearId: int
-    agriculturalLand: float
-    totalCurrentAssests: float
-    agriculturalLandHectaresAdquisition: float
-    longAndMediumTermLoans: float
-    averageHAPrice: float
-    agriculturalLandHectares: float
-
 class CropDataDTO(BaseModel):
 
     cropProductiveArea: int
@@ -195,6 +184,7 @@ class ValueToSPDTO(BaseModel):
     farmCode: int
     holderInfo: Optional[HolderInfoDTO] = None
     cod_RAGR: int
+    cod_RAGR2: int
     cod_RAGR3: int
     technicalEconomicOrientation: int
     altitude: AltitudeEnum
@@ -212,3 +202,30 @@ class IntermediateValueFromLP(BaseModel):
     averageHAPrice: float
     previousAgriculturalLand: float
     result: dict
+
+class LandTransaction(BaseModel):
+    productionId: int
+    destinationFarmId: int
+    yearId: int
+    percentage: float
+    salePrice: float
+
+class AgroManagementDecisions(BaseModel):
+    farmId: int
+    yearId: int
+    agriculturalLand: float
+    longAndMediumTermLoans: float
+    totalCurrentAssets: float
+    averageLandValue: float
+    targetedLandAquisitionArea: float
+    targetedLandAquisitionHectarPrice: float
+    retireAndHandOver: bool
+
+class AgroManagementDecisionFromLP(BaseModel):
+    agroManagementDecisions: List[AgroManagementDecisions]
+    landTransactions: List[LandTransaction]
+
+class DataToLPDTO(BaseModel):
+    values: List[ValueToLPDTO]
+    agriculturalProductions: List[AgriculturalProduction]
+
